@@ -1,3 +1,5 @@
+"""Utilities for building and parsing dryruns."""
+
 import base64
 import copy
 from collections import defaultdict
@@ -21,7 +23,7 @@ from algosdk.v2client.models.asset_holding import AssetHolding
 from algosdk.v2client.models.dryrun_request import DryrunRequest
 from algosdk.v2client.models.teal_key_value import TealKeyValue
 
-from algoappdev.utils import (
+from .utils import (
     ZERO_ADDRESS,
     AlgoAppDevError,
     address_to_idx,
@@ -33,8 +35,13 @@ MAX_SCHEMA = ApplicationStateSchema(64, 64)
 
 
 class TraceItem(NamedTuple):
+    """Information about a call trace line item."""
+
+    # the TEAL source code
     source: str
+    # the stack after this line is executed
     stack: List[Union[int, bytes]]
+    # the program counter (errors report this value)
     program_counter: int
 
     def __str__(self) -> str:
@@ -51,7 +58,11 @@ class TraceItem(NamedTuple):
 
 
 class KeyDelta(NamedTuple):
+    """Information about a key value which changed."""
+
+    # the key
     key: bytes
+    # the new value
     value: int
 
     @staticmethod
@@ -134,8 +145,8 @@ def build_account(
 
 class AppCallCtx:
     """
-    Describes the context (arguments) seen by an app when called by a group
-    of transactions.
+    Build up the full context (arguments) which are accessible by app calls
+    generated by a group of transactions (or a single transaction).
     """
 
     def __init__(self):
